@@ -76,7 +76,7 @@ RadialMap::Widget::paintExplodedLabels(QPainter &paint) const
 {
     //we are a friend of RadialMap::Map
 
-    QList<Label*> list;
+    QVector<Label*> list;
     unsigned int startLevel = 0;
 
 
@@ -151,13 +151,14 @@ RadialMap::Widget::paintExplodedLabels(QPainter &paint) const
     int  *sizes = new int [ m_map.m_visibleDepth + 1 ]; //**** make sizes an array of floats I think instead (or doubles)
 
     // If the minimum is larger than the default it fucks up further down
-    if (paint.font().pointSize() < Config::minFontPitch) {
+    if (paint.font().pointSize() < 0 ||
+        paint.font().pointSize() < Config::minFontPitch) {
         QFont font = paint.font();
         font.setPointSize(Config::minFontPitch);
         paint.setFont(font);
     }
     
-    QList<Label*>::iterator it;
+    QVector<Label*>::iterator it;
 
     do
     {
@@ -331,9 +332,7 @@ RadialMap::Widget::paintExplodedLabels(QPainter &paint) const
         paint.drawText(label->tx, label->ty, label->qs);
     }
 
-    foreach(Label *label, list) {
-        delete label;
-    }
+    qDeleteAll(list);
     delete [] sizes;
 }
 }
